# Lastpass Python CLI

A minimal Python replacement for the Lastpass official CLI.

## Installation

```bash
pip install git+https://github.com/guilt/lastpass-python.git
pip install lastpass-python-cli
```
